aboutsummaryrefslogtreecommitdiffstats
path: root/swarm/storage/localstore/mode_put_test.go
diff options
context:
space:
mode:
Diffstat (limited to 'swarm/storage/localstore/mode_put_test.go')
-rw-r--r--swarm/storage/localstore/mode_put_test.go6
1 files changed, 3 insertions, 3 deletions
diff --git a/swarm/storage/localstore/mode_put_test.go b/swarm/storage/localstore/mode_put_test.go
index ffe6a4cb4..ca034c03e 100644
--- a/swarm/storage/localstore/mode_put_test.go
+++ b/swarm/storage/localstore/mode_put_test.go
@@ -23,7 +23,7 @@ import (
"testing"
"time"
- "github.com/ethereum/go-ethereum/swarm/storage"
+ "github.com/dexon-foundation/dexon/swarm/storage"
)
// TestModePutRequest validates ModePutRequest index values on the provided DB.
@@ -208,11 +208,11 @@ func TestModePutUpload_parallel(t *testing.T) {
//
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014)
//
// # go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkPutUpload -v
//
// goos: darwin
// goarch: amd64
-// pkg: github.com/ethereum/go-ethereum/swarm/storage/localstore
+// pkg: github.com/dexon-foundation/dexon/swarm/storage/localstore
// BenchmarkPutUpload/count_100_parallel_1-8 300 5107704 ns/op 2081461 B/op 2374 allocs/op
// BenchmarkPutUpload/count_100_parallel_2-8 300 5411742 ns/op 2081608 B/op 2364 allocs/op
// BenchmarkPutUpload/count_100_parallel_4-8 500 3704964 ns/op 2081696 B/op 2324 allocs/op
@@ -208,11 +208,11 @@ func TestModePutUpload_parallel(t *testing.T) {
// Measurements on MacBook Pro (Retina, 15-inch, Mid 2014)
//
-// # go test -benchmem -run=none github.com/ethereum/go-ethereum/swarm/storage/localstore -bench BenchmarkPutUpload -v
+// # go test -benchmem -run=none github.com/dexon-foundation/dexon/swarm/storage/localstore -bench BenchmarkPutUpload -v
//
// goos: darwin